/*
 *  SingIt Lyrics Displayer
 *  Copyright (C) 2000 - 2002 Jan-Marek Glogowski <glogow@stud.fbi.fh-darmstadt.de>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */


#ifndef __SINGIT_SOUND_PRECALCS_PRIVATE_H__
#define __SINGIT_SOUND_PRECALCS_PRIVATE_H__

#include "singit/sound_precalcs.h"

#ifdef __cplusplus
extern "C" {
#endif // __cplusplus

void sigit_sound_precalcs_beat(SingitSoundPrecalcs *ssp, gint16 *pcm_data);
void sigit_sound_precalcs_level(SingitSoundPrecalcs *ssp, gint16 *freq_data);

void sigit_sound_precalcs_freq(SingitSoundPrecalcs *ssp, gint16 *freq_data);
void sigit_sound_precalcs_pcm(SingitSoundPrecalcs *ssp, gint16 *pcm_data);

#ifdef __cplusplus
}
#endif // __cplusplus

#endif // __SINGIT_SOUND_PRECALCS_PRIVATE_H__
